@@ -9,15 +9,15 @@ Unit test file for netaddr test plugin: ip_address
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
-import unittest
-from ansible_collections.ansible.utils.plugins.test.ip_address import (
-    _ip_address,
-)
+from unittest import TestCase
+
+from ansible_collections.ansible.utils.plugins.test.ip_address import _ip_address
 
 
-class TestIpAddress(unittest.TestCase):
+class TestIpAddress(TestCase):
     def setUp(self):
         pass
 
