@@ -121,14 +121,10 @@ _list:
 """
 
 from ansible.errors import AnsibleLookupError
-from ansible.module_utils.common._collections_compat import Mapping, Sequence
-from ansible.module_utils.six import string_types
+from collections.abc import Mapping, Sequence
 from ansible.plugins.lookup import LookupBase
-from ansible.release import __version__ as ansible_version
 from ansible.template import Templar
 
-from ansible_collections.community.general.plugins.module_utils.version import LooseVersion
-
 try:
     from ansible.template import trust_as_template as _trust_as_template
     HAS_DATATAGGING = True
@@ -136,11 +132,6 @@ except ImportError:
     HAS_DATATAGGING = False
 
 
-# Whether Templar has a cache, which can be controlled by Templar.template()'s cache option.
-# The cache was removed for ansible-core 2.14 (https://github.com/ansible/ansible/pull/78419)
-_TEMPLAR_HAS_TEMPLATE_CACHE = LooseVersion(ansible_version) < LooseVersion('2.14.0')
-
-
 def _make_safe(value):
     if HAS_DATATAGGING and isinstance(value, str):
         return _trust_as_template(value)
@@ -156,8 +147,6 @@ class LookupModule(LookupBase):
         """
         templar.available_variables = variables or {}
         quoted_expression = "{0}{1}{2}".format("{{", expression, "}}")
-        if _TEMPLAR_HAS_TEMPLATE_CACHE:
-            return templar.template(quoted_expression, cache=False)
         if hasattr(templar, 'evaluate_expression'):
             # This is available since the Data Tagging PR has been merged
             return templar.evaluate_expression(_make_safe(expression))
@@ -207,7 +196,10 @@ class LookupModule(LookupBase):
 
         result = []
         if len(terms) > 0:
-            templar = Templar(loader=self._templar._loader)
+            if HAS_DATATAGGING:
+                templar = self._templar.copy_with_new_env(available_variables={})
+            else:
+                templar = Templar(loader=self._templar._loader)
             data = []
             vars_so_far = set()
             for index, term in enumerate(terms):
@@ -222,7 +214,7 @@ class LookupModule(LookupBase):
                     raise AnsibleLookupError(
                         f'The variable {k!r} appears more than once')
                 vars_so_far.add(k)
-                if isinstance(v, string_types):
+                if isinstance(v, str):
                     data.append((k, v, None))
                 elif isinstance(v, (Sequence, Mapping)):
                     data.append((k, None, v))
