@@ -11,105 +11,110 @@
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: xml
 short_description: Manage bits and pieces of XML files or strings
 description:
-- A CRUD-like interface to managing bits of XML files.
+  - A CRUD-like interface to managing bits of XML files.
+extends_documentation_fragment:
+  - community.general.attributes
+attributes:
+  check_mode:
+    support: full
+  diff_mode:
+    support: full
 options:
   path:
     description:
-    - Path to the file to operate on.
-    - This file must exist ahead of time.
-    - This parameter is required, unless I(xmlstring) is given.
+      - Path to the file to operate on.
+      - This file must exist ahead of time.
+      - This parameter is required, unless O(xmlstring) is given.
     type: path
-    aliases: [ dest, file ]
+    aliases: [dest, file]
   xmlstring:
     description:
-    - A string containing XML on which to operate.
-    - This parameter is required, unless I(path) is given.
+      - A string containing XML on which to operate.
+      - This parameter is required, unless O(path) is given.
     type: str
   xpath:
     description:
-    - A valid XPath expression describing the item(s) you want to manipulate.
-    - Operates on the document root, C(/), by default.
+      - A valid XPath expression describing the item(s) you want to manipulate.
+      - Operates on the document root, V(/), by default.
     type: str
   namespaces:
     description:
-    - The namespace C(prefix:uri) mapping for the XPath expression.
-    - Needs to be a C(dict), not a C(list) of items.
+      - The namespace C(prefix:uri) mapping for the XPath expression.
+      - Needs to be a C(dict), not a C(list) of items.
     type: dict
     default: {}
   state:
     description:
-    - Set or remove an xpath selection (node(s), attribute(s)).
+      - Set or remove an xpath selection (node(s), attribute(s)).
     type: str
-    choices: [ absent, present ]
+    choices: [absent, present]
     default: present
-    aliases: [ ensure ]
+    aliases: [ensure]
   attribute:
     description:
-    - The attribute to select when using parameter I(value).
-    - This is a string, not prepended with C(@).
+      - The attribute to select when using parameter O(value).
+      - This is a string, not prepended with V(@).
     type: raw
   value:
     description:
-    - Desired state of the selected attribute.
-    - Either a string, or to unset a value, the Python C(None) keyword (YAML Equivalent, C(null)).
-    - Elements default to no value (but present).
-    - Attributes default to an empty string.
+      - Desired state of the selected attribute.
+      - Either a string, or to unset a value, the Python V(None) keyword (YAML Equivalent, V(null)).
+      - Elements default to no value (but present).
+      - Attributes default to an empty string.
     type: raw
   add_children:
     description:
-    - Add additional child-element(s) to a selected element for a given I(xpath).
-    - Child elements must be given in a list and each item may be either a string
-      (eg. C(children=ansible) to add an empty C(<ansible/>) child element),
-      or a hash where the key is an element name and the value is the element value.
-    - This parameter requires I(xpath) to be set.
+      - Add additional child-element(s) to a selected element for a given O(xpath).
+      - Child elements must be given in a list and each item may be either a string (for example C(children=ansible) to add
+        an empty C(<ansible/>) child element), or a hash where the key is an element name and the value is the element value.
+      - This parameter requires O(xpath) to be set.
     type: list
     elements: raw
   set_children:
     description:
-    - Set the child-element(s) of a selected element for a given I(xpath).
-    - Removes any existing children.
-    - Child elements must be specified as in I(add_children).
-    - This parameter requires I(xpath) to be set.
+      - Set the child-element(s) of a selected element for a given O(xpath).
+      - Removes any existing children.
+      - Child elements must be specified as in O(add_children).
+      - This parameter requires O(xpath) to be set.
     type: list
     elements: raw
   count:
     description:
-    - Search for a given I(xpath) and provide the count of any matches.
-    - This parameter requires I(xpath) to be set.
+      - Search for a given O(xpath) and provide the count of any matches.
+      - This parameter requires O(xpath) to be set.
     type: bool
     default: false
   print_match:
     description:
-    - Search for a given I(xpath) and print out any matches.
-    - This parameter requires I(xpath) to be set.
+      - Search for a given O(xpath) and print out any matches.
+      - This parameter requires O(xpath) to be set.
     type: bool
     default: false
   pretty_print:
     description:
-    - Pretty print XML output.
+      - Pretty print XML output.
     type: bool
     default: false
   content:
     description:
-    - Search for a given I(xpath) and get content.
-    - This parameter requires I(xpath) to be set.
+      - Search for a given O(xpath) and get content.
+      - This parameter requires O(xpath) to be set.
     type: str
-    choices: [ attribute, text ]
+    choices: [attribute, text]
   input_type:
     description:
-    - Type of input for I(add_children) and I(set_children).
+      - Type of input for O(add_children) and O(set_children).
     type: str
-    choices: [ xml, yaml ]
+    choices: [xml, yaml]
     default: yaml
   backup:
     description:
-      - Create a backup file including the timestamp information so you can get
-        the original file back if you somehow clobbered it incorrectly.
+      - Create a backup file including the timestamp information so you can get the original file back if you somehow clobbered
+        it incorrectly.
     type: bool
     default: false
   strip_cdata_tags:
@@ -120,47 +125,46 @@ options:
     default: false
   insertbefore:
     description:
-      - Add additional child-element(s) before the first selected element for a given I(xpath).
-      - Child elements must be given in a list and each item may be either a string
-        (eg. C(children=ansible) to add an empty C(<ansible/>) child element),
-        or a hash where the key is an element name and the value is the element value.
-      - This parameter requires I(xpath) to be set.
+      - Add additional child-element(s) before the first selected element for a given O(xpath).
+      - Child elements must be given in a list and each item may be either a string (for example C(children=ansible) to add
+        an empty C(<ansible/>) child element), or a hash where the key is an element name and the value is the element value.
+      - This parameter requires O(xpath) to be set.
     type: bool
     default: false
   insertafter:
     description:
-      - Add additional child-element(s) after the last selected element for a given I(xpath).
-      - Child elements must be given in a list and each item may be either a string
-        (eg. C(children=ansible) to add an empty C(<ansible/>) child element),
-        or a hash where the key is an element name and the value is the element value.
-      - This parameter requires I(xpath) to be set.
+      - Add additional child-element(s) after the last selected element for a given O(xpath).
+      - Child elements must be given in a list and each item may be either a string (for example C(children=ansible) to add
+        an empty C(<ansible/>) child element), or a hash where the key is an element name and the value is the element value.
+      - This parameter requires O(xpath) to be set.
     type: bool
     default: false
 requirements:
-- lxml >= 2.3.0
+  - lxml >= 2.3.0
 notes:
-- Use the C(--check) and C(--diff) options when testing your expressions.
-- The diff output is automatically pretty-printed, so may not reflect the actual file content, only the file structure.
-- This module does not handle complicated xpath expressions, so limit xpath selectors to simple expressions.
-- Beware that in case your XML elements are namespaced, you need to use the I(namespaces) parameter, see the examples.
-- Namespaces prefix should be used for all children of an element where namespace is defined, unless another namespace is defined for them.
+  - Use the C(--check) and C(--diff) options when testing your expressions.
+  - The diff output is automatically pretty-printed, so may not reflect the actual file content, only the file structure.
+  - This module does not handle complicated xpath expressions, so limit xpath selectors to simple expressions.
+  - Beware that in case your XML elements are namespaced, you need to use the O(namespaces) parameter, see the examples.
+  - Namespaces prefix should be used for all children of an element where namespace is defined, unless another namespace is
+    defined for them.
 seealso:
-- name: Xml module development community wiki
-  description: More information related to the development of this xml module.
-  link: https://github.com/ansible/community/wiki/Module:-xml
-- name: Introduction to XPath
-  description: A brief tutorial on XPath (w3schools.com).
-  link: https://www.w3schools.com/xml/xpath_intro.asp
-- name: XPath Reference document
-  description: The reference documentation on XSLT/XPath (developer.mozilla.org).
-  link: https://developer.mozilla.org/en-US/docs/Web/XPath
+  - name: XML module development community wiki (archived)
+    description: More information related to the development of this xml module.
+    link: https://github.com/ansible/community/wiki/Module:-xml
+  - name: Introduction to XPath
+    description: A brief tutorial on XPath (w3schools.com).
+    link: https://www.w3schools.com/xml/xpath_intro.asp
+  - name: XPath Reference document
+    description: The reference documentation on XSLT/XPath (developer.mozilla.org).
+    link: https://developer.mozilla.org/en-US/docs/Web/XPath
 author:
-- Tim Bielawa (@tbielawa)
-- Magnus Hedemark (@magnus919)
-- Dag Wieers (@dagwieers)
-'''
+  - Tim Bielawa (@tbielawa)
+  - Magnus Hedemark (@magnus919)
+  - Dag Wieers (@dagwieers)
+"""
 
-EXAMPLES = r'''
+EXAMPLES = r"""
 # Consider the following XML file:
 #
 # <business type="bar">
@@ -212,9 +216,9 @@ EXAMPLES = r'''
     path: /foo/bar.xml
     xpath: /business/beers
     add_children:
-    - beer: Old Rasputin
-    - beer: Old Motor Oil
-    - beer: Old Curmudgeon
+      - beer: Old Rasputin
+      - beer: Old Motor Oil
+      - beer: Old Curmudgeon
 
 - name: Add several more beers to the 'beers' element and add them before the 'Rochefort 10' element
   community.general.xml:
@@ -222,9 +226,9 @@ EXAMPLES = r'''
     xpath: '/business/beers/beer[text()="Rochefort 10"]'
     insertbefore: true
     add_children:
-    - beer: Old Rasputin
-    - beer: Old Motor Oil
-    - beer: Old Curmudgeon
+      - beer: Old Rasputin
+      - beer: Old Motor Oil
+      - beer: Old Curmudgeon
 
 # NOTE: The 'state' defaults to 'present' and 'value' defaults to 'null' for elements
 - name: Add a 'validxhtml' element to the 'website' element
@@ -266,7 +270,7 @@ EXAMPLES = r'''
   community.general.xml:
     path: /foo/bar.xml
     xpath: /business/website
-    children: []
+    set_children: []
 
 # In case of namespaces, like in below XML, they have to be explicitly stated.
 #
@@ -294,14 +298,16 @@ EXAMPLES = r'''
     xpath: /business
     add_children:
       - building:
-          # Attributes
+# Attributes
           name: Scumm bar
           location: Monkey island
+          # Value
+          +value: unreal
           # Subnodes
           _:
             - floor: Pirate hall
             - floor: Grog storage
-            - construction_date: "1990"  # Only strings are valid
+            - construction_date: "1990" # Only strings are valid
       - building: Grog factory
 
 # Consider this XML for following example -
@@ -320,37 +326,36 @@ EXAMPLES = r'''
     path: bar.xml
     xpath: /config/element[@name='test1']
     state: absent
-'''
+"""
 
-RETURN = r'''
+RETURN = r"""
 actions:
-    description: A dictionary with the original xpath, namespaces and state.
-    type: dict
-    returned: success
-    sample: {xpath: xpath, namespaces: [namespace1, namespace2], state=present}
-backup_file:
-    description: The name of the backup file that was created
-    type: str
-    returned: when I(backup=true)
-    sample: /path/to/file.xml.1942.2017-08-24@14:16:01~
+  description: A dictionary with the original xpath, namespaces and state.
+  type: dict
+  returned: success
+  sample:
+    {
+      "xpath": "xpath",
+      "namespaces": [
+        "namespace1",
+        "namespace2"
+      ],
+      "state": "present"
+    }
 count:
-    description: The count of xpath matches.
-    type: int
-    returned: when parameter 'count' is set
-    sample: 2
+  description: The count of xpath matches.
+  type: int
+  returned: when parameter O(count) is set
+  sample: 2
 matches:
-    description: The xpath matches found.
-    type: list
-    returned: when parameter 'print_match' is set
-msg:
-    description: A message related to the performed action(s).
-    type: str
-    returned: always
+  description: The xpath matches found.
+  type: list
+  returned: when parameter O(print_match) is set
 xmlstring:
-    description: An XML string of the resulting output.
-    type: str
-    returned: when parameter 'xmlstring' is set
-'''
+  description: An XML string of the resulting output.
+  type: str
+  returned: when parameter O(xmlstring) is set
+"""
 
 import copy
 import json
@@ -372,8 +377,8 @@ except ImportError:
 
 from ansible.module_utils.basic import AnsibleModule, json_dict_bytes_to_unicode, missing_required_lib
 from ansible.module_utils.six import iteritems, string_types
+from ansible.module_utils.six.moves.collections_abc import MutableMapping
 from ansible.module_utils.common.text.converters import to_bytes, to_native
-from ansible.module_utils.common._collections_compat import MutableMapping
 
 _IDENT = r"[a-zA-Z-][a-zA-Z0-9_\-\.]*"
 _NSIDENT = _IDENT + "|" + _IDENT + ":" + _IDENT
@@ -429,11 +434,16 @@ def is_attribute(tree, xpath, namespaces):
     """ Test if a given xpath matches and that match is an attribute
 
     An xpath attribute search will only match one item"""
+
+    # lxml 5.1.1 removed etree._ElementStringResult, so we can no longer simply assume it is there
+    # (https://github.com/lxml/lxml/commit/eba79343d0e7ad1ce40169f60460cdd4caa29eb3)
+    ElementStringResult = getattr(etree, '_ElementStringResult', None)
+
     if xpath_matches(tree, xpath, namespaces):
         match = tree.xpath(xpath, namespaces=namespaces)
-        if isinstance(match[0], etree._ElementStringResult):
+        if isinstance(match[0], etree._ElementUnicodeResult):
             return True
-        elif isinstance(match[0], etree._ElementUnicodeResult):
+        elif ElementStringResult is not None and isinstance(match[0], ElementStringResult):
             return True
     return False
 
@@ -624,7 +634,7 @@ def check_or_make_target(module, tree, xpath, namespaces):
                 # module.fail_json(msg="now tree=%s" % etree.tostring(tree, pretty_print=True))
             elif eoa == "":
                 for node in tree.xpath(inner_xpath, namespaces=namespaces):
-                    if (node.text != eoa_value):
+                    if node.text != eoa_value:
                         node.text = eoa_value
                         changed = True
 
@@ -747,6 +757,7 @@ def child_to_element(module, child, in_type):
             (key, value) = next(iteritems(child))
             if isinstance(value, MutableMapping):
                 children = value.pop('_', None)
+                child_value = value.pop('+value', None)
 
                 node = etree.Element(key, value)
 
@@ -756,6 +767,9 @@ def child_to_element(module, child, in_type):
 
                     subnodes = children_to_nodes(module, children)
                     node.extend(subnodes)
+
+                if child_value is not None:
+                    node.text = child_value
             else:
                 node = etree.Element(key)
                 node.text = value
@@ -911,29 +925,34 @@ def main():
     elif LooseVersion('.'.join(to_native(f) for f in etree.LXML_VERSION)) < LooseVersion('3.0.0'):
         module.warn('Using lxml version lower than 3.0.0 does not guarantee predictable element attribute order.')
 
-    # Check if the file exists
-    if xml_string:
-        infile = BytesIO(to_bytes(xml_string, errors='surrogate_or_strict'))
-    elif os.path.isfile(xml_file):
-        infile = open(xml_file, 'rb')
-    else:
-        module.fail_json(msg="The target XML source '%s' does not exist." % xml_file)
-
-    # Parse and evaluate xpath expression
-    if xpath is not None:
-        try:
-            etree.XPath(xpath)
-        except etree.XPathSyntaxError as e:
-            module.fail_json(msg="Syntax error in xpath expression: %s (%s)" % (xpath, e))
-        except etree.XPathEvalError as e:
-            module.fail_json(msg="Evaluation error in xpath expression: %s (%s)" % (xpath, e))
-
-    # Try to parse in the target XML file
+    infile = None
     try:
-        parser = etree.XMLParser(remove_blank_text=pretty_print, strip_cdata=strip_cdata_tags)
-        doc = etree.parse(infile, parser)
-    except etree.XMLSyntaxError as e:
-        module.fail_json(msg="Error while parsing document: %s (%s)" % (xml_file or 'xml_string', e))
+        # Check if the file exists
+        if xml_string:
+            infile = BytesIO(to_bytes(xml_string, errors='surrogate_or_strict'))
+        elif os.path.isfile(xml_file):
+            infile = open(xml_file, 'rb')
+        else:
+            module.fail_json(msg="The target XML source '%s' does not exist." % xml_file)
+
+        # Parse and evaluate xpath expression
+        if xpath is not None:
+            try:
+                etree.XPath(xpath)
+            except etree.XPathSyntaxError as e:
+                module.fail_json(msg="Syntax error in xpath expression: %s (%s)" % (xpath, e))
+            except etree.XPathEvalError as e:
+                module.fail_json(msg="Evaluation error in xpath expression: %s (%s)" % (xpath, e))
+
+        # Try to parse in the target XML file
+        try:
+            parser = etree.XMLParser(remove_blank_text=pretty_print, strip_cdata=strip_cdata_tags)
+            doc = etree.parse(infile, parser)
+        except etree.XMLSyntaxError as e:
+            module.fail_json(msg="Error while parsing document: %s (%s)" % (xml_file or 'xml_string', e))
+    finally:
+        if infile:
+            infile.close()
 
     # Ensure we have the original copy to compare
     global orig_doc
@@ -961,7 +980,7 @@ def main():
     # add_children && set_children both set?: should have already aborted by now
 
     # set_children set?
-    if set_children:
+    if set_children is not None:
         set_target_children(module, doc, xpath, namespaces, set_children, input_type)
 
     # add_children set?
