@@ -12,12 +12,14 @@ from ansible_collections.community.general.plugins.connection.wsl import authent
 from ansible_collections.community.general.plugins.module_utils._filelock import FileLock, LockTimeout
 from ansible.errors import AnsibleError, AnsibleAuthenticationFailure, AnsibleConnectionFailure
 from ansible.module_utils.common.text.converters import to_bytes
-from ansible.module_utils.compat.paramiko import paramiko
 from ansible.playbook.play_context import PlayContext
 from ansible.plugins.loader import connection_loader
 from io import StringIO
 from pathlib import Path
-from unittest.mock import patch, MagicMock, mock_open
+from ansible_collections.community.internal_test_tools.tests.unit.compat.mock import patch, MagicMock, mock_open
+
+
+paramiko = pytest.importorskip('paramiko')
 
 
 @pytest.fixture
