@@ -1,4 +1,4 @@
-# (c) 2022, NetApp, Inc
+# (c) 2022-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 # Author: Laurent Nicolas, laurentn@netapp.com
 
@@ -52,6 +52,13 @@ _DEFAULT_RESPONSES = {
     'is_rest_9_10_1': (200, dict(version=dict(generation=9, major=10, minor=1, full='dummy_9_10_1')), None),
     'is_rest_9_11_0': (200, dict(version=dict(generation=9, major=11, minor=0, full='dummy_9_11_0')), None),
     'is_rest_9_11_1': (200, dict(version=dict(generation=9, major=11, minor=1, full='dummy_9_11_1')), None),
+    'is_rest_9_12_0': (200, dict(version=dict(generation=9, major=12, minor=0, full='dummy_9_12_0')), None),
+    'is_rest_9_12_1': (200, dict(version=dict(generation=9, major=12, minor=1, full='dummy_9_12_1')), None),
+    'is_rest_9_13_1': (200, dict(version=dict(generation=9, major=13, minor=1, full='dummy_9_13_1')), None),
+    'is_rest_9_14_1': (200, dict(version=dict(generation=9, major=14, minor=1, full='dummy_9_14_1')), None),
+    'is_rest_9_15_1': (200, dict(version=dict(generation=9, major=15, minor=1, full='dummy_9_15_1')), None),
+    'is_rest_9_16_1': (200, dict(version=dict(generation=9, major=16, minor=1, full='dummy_9_16_1')), None),
+    'is_rest_9_17_1': (200, dict(version=dict(generation=9, major=17, minor=1, full='dummy_9_17_1')), None),
     'is_zapi': (400, {}, "Unreachable"),
     'empty_good': (200, {}, None),
     'success': (200, {}, None),
@@ -60,6 +67,7 @@ _DEFAULT_RESPONSES = {
     'empty_records': (200, {'records': []}, None),
     'zero_records': (200, {'num_records': 0}, None),
     'one_record': (200, {'num_records': 1}, None),
+    'one_vserver_record': (200, {'num_records': 1, 'records': [{'svm': {'name': 'svm_name', 'uuid': 'svm_uuid'}}]}, None),
     'generic_error': (400, None, "Expected error"),
     'error_record': (400, None, {'code': 6, 'message': 'Expected error'}),
     'job_generic_response_success': _build_job('success'),
