@@ -99,7 +99,7 @@ class TestVmwareRemoteOvf(ModuleTestCase):
         mocker.patch.object(os.path, 'getsize', return_value=10)
         mocker.patch.object(os, 'listdir', return_value=['foo', 'foo.ovf', 'foo.vmdk'])
         mocker.patch("builtins.open", new_callable=mocker.mock_open, read_data="data")
-        mocker.patch('ansible_collections.vmware.vmware.plugins.modules.import_content_library_ovf.open_url')
+        mocker.patch('requests.post')
 
         result = run_module(module_entry=module_main, module_args=module_args)
 
