@@ -18,39 +18,35 @@
 # Make coding more python3-ish
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
-from ansible_collections.vyos.vyos.tests.unit.compat.mock import patch
+from unittest.mock import patch
+
 from ansible_collections.vyos.vyos.plugins.modules import vyos_snmp_server
-from ansible_collections.vyos.vyos.tests.unit.modules.utils import (
-    set_module_args,
-)
+from ansible_collections.vyos.vyos.tests.unit.modules.utils import set_module_args
+
 from .vyos_module import TestVyosModule, load_fixture
 
 
 class TestVyosSnmpServerModule(TestVyosModule):
-
     module = vyos_snmp_server
 
     def setUp(self):
         super(TestVyosSnmpServerModule, self).setUp()
 
         self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base.get_resource_connection"
-        )
-        self.get_resource_connection_config = (
-            self.mock_get_resource_connection_config.start()
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base.get_resource_connection",
         )
+        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
 
         self.mock_get_resource_connection_facts = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts.get_resource_connection"
-        )
-        self.get_resource_connection_facts = (
-            self.mock_get_resource_connection_facts.start()
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts.get_resource_connection",
         )
+        self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
         self.mock_execute_show_command = patch(
-            "ansible_collections.vyos.vyos.plugins.module_utils.network.vyos.facts.snmp_server.snmp_server.Snmp_serverFacts.get_config"
+            "ansible_collections.vyos.vyos.plugins.module_utils.network.vyos.facts.snmp_server.snmp_server.Snmp_serverFacts.get_config",
         )
 
         self.execute_show_command = self.mock_execute_show_command.start()
@@ -79,7 +75,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         dict(
                             name="bridges",
                             networks=["12.1.1.0/24", "1.1.1.0/24"],
-                        )
+                        ),
                     ],
                     listen_addresses=[
                         dict(address="100.1.2.1", port=33),
@@ -89,27 +85,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         users=[
                             dict(
                                 user="admin_user",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                             dict(
                                 user="guest_user",
-                                authentication=dict(
-                                    type="sha", plaintext_key="opq1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="opq1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="opq1234567"),
+                                privacy=dict(type="aes", plaintext_key="opq1234567"),
                             ),
-                        ]
+                        ],
                     ),
                 ),
                 state="merged",
-            )
+            ),
         )
         self.execute_module(changed=False, commands=[])
 
@@ -121,7 +109,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         dict(
                             name="bridges",
                             networks=["12.1.1.0/24", "1.1.1.0/24"],
-                        )
+                        ),
                     ],
                     listen_addresses=[
                         dict(address="100.1.2.1", port=33),
@@ -131,27 +119,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         users=[
                             dict(
                                 user="admin_user",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                             dict(
                                 user="guest_user",
-                                authentication=dict(
-                                    type="sha", plaintext_key="opq1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="opq1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="opq1234567"),
+                                privacy=dict(type="aes", plaintext_key="opq1234567"),
                             ),
-                        ]
+                        ],
                     ),
                 ),
                 state="replaced",
-            )
+            ),
         )
         self.execute_module(changed=False, commands=[])
 
@@ -163,7 +143,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         dict(
                             name="bridges",
                             networks=["12.1.1.0/24", "1.1.1.0/24"],
-                        )
+                        ),
                     ],
                     listen_addresses=[
                         dict(address="100.1.2.1", port=33),
@@ -173,27 +153,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         users=[
                             dict(
                                 user="admin_user",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                             dict(
                                 user="guest_user",
-                                authentication=dict(
-                                    type="sha", plaintext_key="opq1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="opq1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="opq1234567"),
+                                privacy=dict(type="aes", plaintext_key="opq1234567"),
                             ),
-                        ]
+                        ],
                     ),
                 ),
                 state="overridden",
-            )
+            ),
         )
         self.execute_module(changed=False, commands=[])
 
@@ -213,9 +185,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                     description="snmp_config",
                     smux_peer="peer1",
                     trap_source="1.1.1.1",
-                    trap_target=dict(
-                        address="10.10.1.1", community="switches", port="80"
-                    ),
+                    trap_target=dict(address="10.10.1.1", community="switches", port="80"),
                     snmp_v3=dict(
                         engine_id="34",
                         groups=[
@@ -224,23 +194,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                                 mode="rw",
                                 seclevel="priv",
                                 view="view1",
-                            )
+                            ),
                         ],
                         trap_targets=[
                             dict(
                                 address="20.12.1.1",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                         ],
                     ),
                 ),
                 state="merged",
-            )
+            ),
         )
         commands = [
             "set service snmp community routers client 1.1.1.0/24",
@@ -275,9 +241,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                     description="snmp_config",
                     smux_peer="peer1",
                     trap_source="1.1.1.1",
-                    trap_target=dict(
-                        address="10.10.1.1", community="switches", port="80"
-                    ),
+                    trap_target=dict(address="10.10.1.1", community="switches", port="80"),
                     snmp_v3=dict(
                         engine_id="34",
                         groups=[
@@ -286,23 +250,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                                 mode="rw",
                                 seclevel="priv",
                                 view="view1",
-                            )
+                            ),
                         ],
                         trap_targets=[
                             dict(
                                 address="20.12.1.1",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                         ],
                     ),
                 ),
                 state="replaced",
-            )
+            ),
         )
         commands = [
             "set service snmp community routers client 1.1.1.0/24",
@@ -316,13 +276,13 @@ class TestVyosSnmpServerModule(TestVyosModule):
             "set service snmp v3 group default seclevel priv",
             "set service snmp v3 group default view view1",
             "delete service snmp v3 user admin_user auth type sha",
-            "delete service snmp v3 user admin_user auth plaintext-key abc1234567",
+            "delete service snmp v3 user admin_user auth plaintext-password abc1234567",
             "delete service snmp v3 user admin_user privacy type aes",
-            "delete service snmp v3 user admin_user privacy plaintext-key abc1234567",
+            "delete service snmp v3 user admin_user privacy plaintext-password abc1234567",
             "delete service snmp v3 user guest_user auth type sha",
-            "delete service snmp v3 user guest_user auth plaintext-key opq1234567",
+            "delete service snmp v3 user guest_user auth plaintext-password opq1234567",
             "delete service snmp v3 user guest_user privacy type aes",
-            "delete service snmp v3 user guest_user privacy plaintext-key opq1234567",
+            "delete service snmp v3 user guest_user privacy plaintext-password opq1234567",
             "set service snmp v3 engineid 34",
             "set service snmp contact admin@example.com",
             "set service snmp description snmp_config",
@@ -350,9 +310,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                     description="snmp_config",
                     smux_peer="peer1",
                     trap_source="1.1.1.1",
-                    trap_target=dict(
-                        address="10.10.1.1", community="switches", port="80"
-                    ),
+                    trap_target=dict(address="10.10.1.1", community="switches", port="80"),
                     snmp_v3=dict(
                         engine_id="34",
                         groups=[
@@ -361,23 +319,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                                 mode="rw",
                                 seclevel="priv",
                                 view="view1",
-                            )
+                            ),
                         ],
                         trap_targets=[
                             dict(
                                 address="20.12.1.1",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                         ],
                     ),
                 ),
                 state="overridden",
-            )
+            ),
         )
         commands = [
             "set service snmp community routers client 1.1.1.0/24",
@@ -391,13 +345,13 @@ class TestVyosSnmpServerModule(TestVyosModule):
             "set service snmp v3 group default seclevel priv",
             "set service snmp v3 group default view view1",
             "delete service snmp v3 user admin_user auth type sha",
-            "delete service snmp v3 user admin_user auth plaintext-key abc1234567",
+            "delete service snmp v3 user admin_user auth plaintext-password abc1234567",
             "delete service snmp v3 user admin_user privacy type aes",
-            "delete service snmp v3 user admin_user privacy plaintext-key abc1234567",
+            "delete service snmp v3 user admin_user privacy plaintext-password abc1234567",
             "delete service snmp v3 user guest_user auth type sha",
-            "delete service snmp v3 user guest_user auth plaintext-key opq1234567",
+            "delete service snmp v3 user guest_user auth plaintext-password opq1234567",
             "delete service snmp v3 user guest_user privacy type aes",
-            "delete service snmp v3 user guest_user privacy plaintext-key opq1234567",
+            "delete service snmp v3 user guest_user privacy plaintext-password opq1234567",
             "set service snmp v3 engineid 34",
             "set service snmp contact admin@example.com",
             "set service snmp description snmp_config",
@@ -413,7 +367,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
         set_module_args(
             dict(
                 state="deleted",
-            )
+            ),
         )
         commands = ["delete service snmp"]
         self.execute_module(changed=True, commands=commands)
@@ -434,9 +388,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                     description="snmp_config",
                     smux_peer="peer1",
                     trap_source="1.1.1.1",
-                    trap_target=dict(
-                        address="10.10.1.1", community="switches", port="80"
-                    ),
+                    trap_target=dict(address="10.10.1.1", community="switches", port="80"),
                     snmp_v3=dict(
                         engine_id="34",
                         groups=[
@@ -445,23 +397,19 @@ class TestVyosSnmpServerModule(TestVyosModule):
                                 mode="rw",
                                 seclevel="priv",
                                 view="view1",
-                            )
+                            ),
                         ],
                         trap_targets=[
                             dict(
                                 address="20.12.1.1",
-                                authentication=dict(
-                                    type="sha", plaintext_key="abc1234567"
-                                ),
-                                privacy=dict(
-                                    type="aes", plaintext_key="abc1234567"
-                                ),
+                                authentication=dict(type="sha", plaintext_key="abc1234567"),
+                                privacy=dict(type="aes", plaintext_key="abc1234567"),
                             ),
                         ],
                     ),
                 ),
                 state="rendered",
-            )
+            ),
         )
         commands = [
             "set service snmp community routers client 1.1.1.0/24",
@@ -524,7 +472,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         "mode": "rw",
                         "seclevel": "priv",
                         "view": "view1",
-                    }
+                    },
                 ],
             },
             "trap_source": "1.1.1.1",
@@ -565,7 +513,7 @@ class TestVyosSnmpServerModule(TestVyosModule):
                         },
                         "user": "guest_user",
                     },
-                ]
+                ],
             },
         }
         self.assertEqual(gathered_list, result["gathered"])
